<img width="300px" src="https://sickrage.ca/img/logo-stacked.png" />

# 

##Sun Nov 15 2020 22:01:35 GMT+0000 (Coordinated Universal Time)


## Bug Fixes
  - Fixed recursion error in StatusStrings class
  ([cddcbcb5](https://gitlab-ci-token:dimWx4VDK_qWJi12PKQF@git.sickrage.ca/SiCKRAGE/sickrage/commit/cddcbcb5042a96f5d01ce9cd1b9647401c9ba7d2))




## Refactor
  - Refactored series API endpoint for adding shows to accommodate adding existing shows as well
  ([0207fe83](https://gitlab-ci-token:dimWx4VDK_qWJi12PKQF@git.sickrage.ca/SiCKRAGE/sickrage/commit/0207fe83f3c601e00419ba87803a5b3f312eabfa))




